#!/usr/bin/python
# encoding: utf-8
"""
==================================AI写真==================================
"""
import requests
import json
import base64
import hashlib
import uuid


class Idphoto:
    def __init__(self, appcode, timeout=7):
        self.appcode = appcode
        self.timeout = timeout

        self.idphoto_preview_url = "https://swapface-api.segapi.com/swapface"

        self.headers = {
            'Authorization': 'APPCODE ' + appcode,
        }

    def get_md5_data(self, body):
        """
        md5加密
        :param body_json:
        :return:
        """

        md5lib = hashlib.md5()
        md5lib.update(body.encode("utf-8"))
        body_md5 = md5lib.digest()
        body_md5 = base64.b64encode(body_md5)
        return body_md5


    def aiseg_request(self, url, data, headers):
        resp = requests.post(url=url, data=data, headers=headers, timeout=self.timeout)
        res = {"status_code": resp.status_code}
        try:
            res["data"] = json.loads(resp.text)
            return res
        except Exception as e:
            print(e)

    def portrait_ai(self, source_url, target_url, notify_url, timeout):
        """
        AI写真
        :param file_path:
        :return:
        """
        body_json = {
            "source_url": source_url,
            "target_url": target_url,
            "notify_url": notify_url,
            "timeout": timeout
        }

        body = json.dumps(body_json)
        body_md5 = self.get_md5_data(body=body)
        self.headers.update({'Content-MD5': body_md5})
        self.headers.update({'X-Ca-Nonce': str(uuid.uuid4())})

        data = self.aiseg_request(url=self.idphoto_preview_url, data=body, headers=self.headers)
        return data


if __name__ == "__main__":
    appcode = "你的appcode"
    source_url = "https://ts-mmqi-1259176759.cos.ap-beijing.myqcloud.com/aliyun_api_img/source_img.jpg"  # 用户原图
    target_url = "https://ts-mmqi-1259176759.cos.ap-beijing.myqcloud.com/aliyun_api_img/target_img.jpg"  # 模版图

    notify_url = "https://www.baidu.com"  # 回调地址

    timeout = 600
    idphoto = Idphoto(appcode=appcode)
    d = idphoto.portrait_ai(source_url, target_url, notify_url, timeout)
    print(d)
